@@ -13,7 +13,7 @@ use egg_mode::{
 use std::{
     clone::Clone,
     fs,
-    io::{stdout, Stdout, Write},
+    io::{stdin, stdout, Read, Stdout, Write},
     iter::Iterator,
     process::exit,
 };
@@ -154,17 +154,48 @@ fn get_key() -> char {
     }
 }
 
-fn clear_screen() {
+fn get_line(terminal: &mut Term) -> Option<String> {
+    let mut line = String::new();
+    let mut abort: bool = false;
+    for byte in stdin().bytes() {
+        let next_char = byte.unwrap() as char;
+        match next_char {
+            '\x1B' => {
+                abort = true;
+                break;
+            }
+            '\n' => {
+                abort = false;
+                break;
+            }
+            c => {
+                print!("{}", c);
+                stdout().flush().unwrap();
+                line.push(c);
+            }
+        }
+    }
+    terminal.clear().unwrap();
+
+    if abort {
+        None
+    } else {
+        Some(line)
+    }
+}
+
+fn prepare_exit() {
     stdout()
         .execute(terminal::Clear(terminal::ClearType::All))
         .unwrap()
         .execute(MoveTo(0, 0))
         .unwrap();
+    terminal::disable_raw_mode().unwrap();
 }
 
 async fn run_action(tweet: &Tweet, key: char, token: &Token, terminal: &mut Term) -> String {
     if key == 'x' {
-        clear_screen();
+        prepare_exit();
         exit(0);
     };
     if key == 'l' {
@@ -173,7 +204,7 @@ async fn run_action(tweet: &Tweet, key: char, token: &Token, terminal: &mut Term
             Err(e) => err_view(e),
         }
     } else if key == 'r' {
-        terminal::disable_raw_mode().unwrap();
+        // terminal::disable_raw_mode().unwrap();
         draw(
             tweet_view(tweet),
             vec![Spans::from("Your reply:")],
@@ -181,11 +212,16 @@ async fn run_action(tweet: &Tweet, key: char, token: &Token, terminal: &mut Term
         );
         let height = terminal::size().unwrap().1;
         stdout().execute(MoveTo(13, height - 2)).unwrap();
-        let reply = read!();
-        terminal::enable_raw_mode().unwrap();
-        match send_reply(tweet, reply, token).await {
-            Ok(()) => "Done!".to_string(),
-            Err(e) => err_view(e),
+        let reply = get_line(terminal);
+        // terminal::enable_raw_mode().unwrap();
+
+        if reply.is_some() {
+            match send_reply(tweet, reply.unwrap(), token).await {
+                Ok(()) => "Done!".to_string(),
+                Err(e) => err_view(e),
+            }
+        } else {
+            "Aborted.".to_string()
         }
     } else {
         "You can't do that".to_string()
@@ -260,5 +296,5 @@ async fn main() {
         }
     }
 
-    clear_screen();
+    prepare_exit();
 }
